==> ngx-if-empty-or-has-items-0.2.0.tgz: package/index.js <==
import { Directive, Input, NgModule, TemplateRef, ViewContainerRef } from '@angular/core';
import isEmpty from 'lodash/isEmpty';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfEmptyDirective = (function () {
    function NgxIfEmptyDirective(_viewContainer, templateRef) {
        this._viewContainer = _viewContainer;
        this._context = new NgxIfEmptyContext();
        this._thenTemplateRef = null;
        this._elseTemplateRef = null;
        this._thenViewRef = null;
        this._elseViewRef = null;
        this._thenTemplateRef = templateRef;
    }
    Object.defineProperty(NgxIfEmptyDirective.prototype, "ngxIfEmpty", {
        set: /**
         * @param {?} array
         * @return {?}
         */
        function (array) {
            this._context.ngxIfEmpty = array;
            this._context.$implicit = isEmpty(array);
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfEmptyDirective.prototype, "ngxIfEmptyThen", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate("ngxIfEmptyThen", templateRef);
            this._thenTemplateRef = templateRef;
            this._thenViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfEmptyDirective.prototype, "ngxIfEmptyElse", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate("ngxIfEmptyElse", templateRef);
            this._elseTemplateRef = templateRef;
            this._elseViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NgxIfEmptyDirective.prototype._updateView = /**
     * @return {?}
     */
    function () {
        if (this._context.$implicit) {
            if (!this._thenViewRef) {
                this._viewContainer.clear();
                this._elseViewRef = null;
                if (this._thenTemplateRef) {
                    this._thenViewRef =
                        this._viewContainer.createEmbeddedView(this._thenTemplateRef, this._context);
                }
            }
        }
        else {
            if (!this._elseViewRef) {
                this._viewContainer.clear();
                this._thenViewRef = null;
                if (this._elseTemplateRef) {
                    this._elseViewRef =
                        this._viewContainer.createEmbeddedView(this._elseTemplateRef, this._context);
                }
            }
        }
    };
    NgxIfEmptyDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[ngxIfEmpty]'
                },] },
    ];
    /** @nocollapse */
    NgxIfEmptyDirective.ctorParameters = function () { return [
        { type: ViewContainerRef, },
        { type: TemplateRef, },
    ]; };
    NgxIfEmptyDirective.propDecorators = {
        "ngxIfEmpty": [{ type: Input },],
        "ngxIfEmptyThen": [{ type: Input },],
        "ngxIfEmptyElse": [{ type: Input },],
    };
    return NgxIfEmptyDirective;
}());
var NgxIfEmptyContext = (function () {
    function NgxIfEmptyContext() {
        this.$implicit = null;
        this.ngxIfEmpty = null;
    }
    return NgxIfEmptyContext;
}());
/**
 * @param {?} property
 * @param {?} templateRef
 * @return {?}
 */
function assertTemplate(property, templateRef) {
    var /** @type {?} */ isTemplateRefOrNull = !!(!templateRef || templateRef.createEmbeddedView);
    if (!isTemplateRefOrNull) {
        throw new Error(property + " must be a TemplateRef, but received '" + (templateRef) + "'.");
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfEmptyModule = (function () {
    function NgxIfEmptyModule() {
    }
    NgxIfEmptyModule.decorators = [
        { type: NgModule, args: [{
                    imports: [],
                    declarations: [
                        NgxIfEmptyDirective
                    ],
                    exports: [
                        NgxIfEmptyDirective
                    ]
                },] },
    ];
    return NgxIfEmptyModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfHasItemsDirective = (function () {
    function NgxIfHasItemsDirective(_viewContainer, templateRef) {
        this._viewContainer = _viewContainer;
        this._context = new NgxIfHasItemsContext();
        this._thenTemplateRef = null;
        this._elseTemplateRef = null;
        this._thenViewRef = null;
        this._elseViewRef = null;
        this._thenTemplateRef = templateRef;
    }
    Object.defineProperty(NgxIfHasItemsDirective.prototype, "ngxIfHasItems", {
        set: /**
         * @param {?} array
         * @return {?}
         */
        function (array) {
            this._context.ngxIfHasItems = array;
            this._context.$implicit = !isEmpty(array);
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfHasItemsDirective.prototype, "ngxIfHasItemsThen", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate$1("ngxIfHasItemsThen", templateRef);
            this._thenTemplateRef = templateRef;
            this._thenViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfHasItemsDirective.prototype, "ngxIfHasItemsElse", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate$1("ngxIfHasItemsElse", templateRef);
            this._elseTemplateRef = templateRef;
            this._elseViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NgxIfHasItemsDirective.prototype._updateView = /**
     * @return {?}
     */
    function () {
        if (this._context.$implicit) {
            if (!this._thenViewRef) {
                this._viewContainer.clear();
                this._elseViewRef = null;
                if (this._thenTemplateRef) {
                    this._thenViewRef =
                        this._viewContainer.createEmbeddedView(this._thenTemplateRef, this._context);
                }
            }
        }
        else {
            if (!this._elseViewRef) {
                this._viewContainer.clear();
                this._thenViewRef = null;
                if (this._elseTemplateRef) {
                    this._elseViewRef =
                        this._viewContainer.createEmbeddedView(this._elseTemplateRef, this._context);
                }
            }
        }
    };
    NgxIfHasItemsDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[ngxIfHasItems]"
                },] },
    ];
    /** @nocollapse */
    NgxIfHasItemsDirective.ctorParameters = function () { return [
        { type: ViewContainerRef, },
        { type: TemplateRef, },
    ]; };
    NgxIfHasItemsDirective.propDecorators = {
        "ngxIfHasItems": [{ type: Input },],
        "ngxIfHasItemsThen": [{ type: Input },],
        "ngxIfHasItemsElse": [{ type: Input },],
    };
    return NgxIfHasItemsDirective;
}());
var NgxIfHasItemsContext = (function () {
    function NgxIfHasItemsContext() {
        this.$implicit = null;
        this.ngxIfHasItems = null;
    }
    return NgxIfHasItemsContext;
}());
/**
 * @param {?} property
 * @param {?} templateRef
 * @return {?}
 */
function assertTemplate$1(property, templateRef) {
    var /** @type {?} */ isTemplateRefOrNull = !!(!templateRef || templateRef.createEmbeddedView);
    if (!isTemplateRefOrNull) {
        throw new Error(property + " must be a TemplateRef, but received '" + (templateRef) + "'.");
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfHasItemsModule = (function () {
    function NgxIfHasItemsModule() {
    }
    NgxIfHasItemsModule.decorators = [
        { type: NgModule, args: [{
                    imports: [],
                    declarations: [
                        NgxIfHasItemsDirective
                    ],
                    exports: [
                        NgxIfHasItemsDirective
                    ]
                },] },
    ];
    return NgxIfHasItemsModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfNotEmptyDirective = (function () {
    function NgxIfNotEmptyDirective(_viewContainer, templateRef) {
        this._viewContainer = _viewContainer;
        this._context = new NgxIfNotEmptyContext();
        this._thenTemplateRef = null;
        this._elseTemplateRef = null;
        this._thenViewRef = null;
        this._elseViewRef = null;
        this._thenTemplateRef = templateRef;
    }
    Object.defineProperty(NgxIfNotEmptyDirective.prototype, "ngxIfNotEmpty", {
        set: /**
         * @param {?} array
         * @return {?}
         */
        function (array) {
            this._context.ngxIfNotEmpty = array;
            this._context.$implicit = !isEmpty(array);
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfNotEmptyDirective.prototype, "ngxIfNotEmptyThen", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate$2("ngxIfNotEmptyThen", templateRef);
            this._thenTemplateRef = templateRef;
            this._thenViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfNotEmptyDirective.prototype, "ngxIfNotEmptyElse", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate$2("ngxIfNotEmptyElse", templateRef);
            this._elseTemplateRef = templateRef;
            this._elseViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NgxIfNotEmptyDirective.prototype._updateView = /**
     * @return {?}
     */
    function () {
        if (this._context.$implicit) {
            if (!this._thenViewRef) {
                this._viewContainer.clear();
                this._elseViewRef = null;
                if (this._thenTemplateRef) {
                    this._thenViewRef =
                        this._viewContainer.createEmbeddedView(this._thenTemplateRef, this._context);
                }
            }
        }
        else {
            if (!this._elseViewRef) {
                this._viewContainer.clear();
                this._thenViewRef = null;
                if (this._elseTemplateRef) {
                    this._elseViewRef =
                        this._viewContainer.createEmbeddedView(this._elseTemplateRef, this._context);
                }
            }
        }
    };
    NgxIfNotEmptyDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[ngxIfNotEmpty]"
                },] },
    ];
    /** @nocollapse */
    NgxIfNotEmptyDirective.ctorParameters = function () { return [
        { type: ViewContainerRef, },
        { type: TemplateRef, },
    ]; };
    NgxIfNotEmptyDirective.propDecorators = {
        "ngxIfNotEmpty": [{ type: Input },],
        "ngxIfNotEmptyThen": [{ type: Input },],
        "ngxIfNotEmptyElse": [{ type: Input },],
    };
    return NgxIfNotEmptyDirective;
}());
var NgxIfNotEmptyContext = (function () {
    function NgxIfNotEmptyContext() {
        this.$implicit = null;
        this.ngxIfNotEmpty = null;
    }
    return NgxIfNotEmptyContext;
}());
/**
 * @param {?} property
 * @param {?} templateRef
 * @return {?}
 */
function assertTemplate$2(property, templateRef) {
    var /** @type {?} */ isTemplateRefOrNull = !!(!templateRef || templateRef.createEmbeddedView);
    if (!isTemplateRefOrNull) {
        throw new Error(property + " must be a TemplateRef, but received '" + (templateRef) + "'.");
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfNotEmptyModule = (function () {
    function NgxIfNotEmptyModule() {
    }
    NgxIfNotEmptyModule.decorators = [
        { type: NgModule, args: [{
                    imports: [],
                    declarations: [
                        NgxIfNotEmptyDirective
                    ],
                    exports: [
                        NgxIfNotEmptyDirective
                    ]
                },] },
    ];
    return NgxIfNotEmptyModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfEmptyOrHasItemsModule = (function () {
    function NgxIfEmptyOrHasItemsModule() {
    }
    NgxIfEmptyOrHasItemsModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        NgxIfEmptyModule,
                        NgxIfHasItemsModule,
                        NgxIfNotEmptyModule
                    ],
                    exports: [
                        NgxIfEmptyModule,
                        NgxIfHasItemsModule,
                        NgxIfNotEmptyModule
                    ]
                },] },
    ];
    return NgxIfEmptyOrHasItemsModule;
}());

export { NgxIfEmptyOrHasItemsModule, NgxIfEmptyModule, NgxIfEmptyDirective, NgxIfEmptyContext, NgxIfHasItemsModule, NgxIfHasItemsDirective, NgxIfHasItemsContext, NgxIfNotEmptyModule, NgxIfNotEmptyDirective, NgxIfNotEmptyContext };

==> ngx-if-empty-or-has-items-1.0.2.tgz: package/index.js <==
import { ChangeDetectorRef, Directive, Input, NgModule, TemplateRef, ViewContainerRef } from '@angular/core';
import isEmpty from 'lodash/isEmpty';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfEmptyDirective = (function () {
    function NgxIfEmptyDirective(_viewContainer, templateRef, cd) {
        this._viewContainer = _viewContainer;
        this.cd = cd;
        this._context = new NgxIfEmptyContext();
        this._thenTemplateRef = null;
        this._elseTemplateRef = null;
        this._thenViewRef = null;
        this._elseViewRef = null;
        this._thenTemplateRef = templateRef;
    }
    Object.defineProperty(NgxIfEmptyDirective.prototype, "ngxIfEmpty", {
        set: /**
         * @param {?} array
         * @return {?}
         */
        function (array) {
            this._context.ngxIfEmpty = array;
            this._context.$implicit = isEmpty(array);
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfEmptyDirective.prototype, "ngxIfEmptyThen", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate("ngxIfEmptyThen", templateRef);
            this._thenTemplateRef = templateRef;
            this._thenViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfEmptyDirective.prototype, "ngxIfEmptyElse", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate("ngxIfEmptyElse", templateRef);
            this._elseTemplateRef = templateRef;
            this._elseViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NgxIfEmptyDirective.prototype._updateView = /**
     * @return {?}
     */
    function () {
        if (this._context.$implicit) {
            if (!this._thenViewRef) {
                this._viewContainer.clear();
                this._elseViewRef = null;
                if (this._thenTemplateRef) {
                    this._thenViewRef =
                        this._viewContainer.createEmbeddedView(this._thenTemplateRef, this._context);
                }
            }
        }
        else {
            if (!this._elseViewRef) {
                this._viewContainer.clear();
                this._thenViewRef = null;
                if (this._elseTemplateRef) {
                    this._elseViewRef =
                        this._viewContainer.createEmbeddedView(this._elseTemplateRef, this._context);
                }
            }
        }
        this.cd.markForCheck();
    };
    NgxIfEmptyDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[ngxIfEmpty]'
                },] },
    ];
    /** @nocollapse */
    NgxIfEmptyDirective.ctorParameters = function () { return [
        { type: ViewContainerRef, },
        { type: TemplateRef, },
        { type: ChangeDetectorRef, },
    ]; };
    NgxIfEmptyDirective.propDecorators = {
        "ngxIfEmpty": [{ type: Input },],
        "ngxIfEmptyThen": [{ type: Input },],
        "ngxIfEmptyElse": [{ type: Input },],
    };
    return NgxIfEmptyDirective;
}());
var NgxIfEmptyContext = (function () {
    function NgxIfEmptyContext() {
        this.$implicit = null;
        this.ngxIfEmpty = null;
    }
    return NgxIfEmptyContext;
}());
/**
 * @param {?} property
 * @param {?} templateRef
 * @return {?}
 */
function assertTemplate(property, templateRef) {
    var /** @type {?} */ isTemplateRefOrNull = !!(!templateRef || templateRef.createEmbeddedView);
    if (!isTemplateRefOrNull) {
        throw new Error(property + " must be a TemplateRef, but received '" + (templateRef) + "'.");
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfEmptyModule = (function () {
    function NgxIfEmptyModule() {
    }
    NgxIfEmptyModule.decorators = [
        { type: NgModule, args: [{
                    imports: [],
                    declarations: [
                        NgxIfEmptyDirective
                    ],
                    exports: [
                        NgxIfEmptyDirective
                    ]
                },] },
    ];
    return NgxIfEmptyModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfHasItemsDirective = (function () {
    function NgxIfHasItemsDirective(_viewContainer, templateRef, cd) {
        this._viewContainer = _viewContainer;
        this.cd = cd;
        this._context = new NgxIfHasItemsContext();
        this._thenTemplateRef = null;
        this._elseTemplateRef = null;
        this._thenViewRef = null;
        this._elseViewRef = null;
        this._thenTemplateRef = templateRef;
    }
    Object.defineProperty(NgxIfHasItemsDirective.prototype, "ngxIfHasItems", {
        set: /**
         * @param {?} array
         * @return {?}
         */
        function (array) {
            this._context.ngxIfHasItems = array;
            this._context.$implicit = !isEmpty(array);
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfHasItemsDirective.prototype, "ngxIfHasItemsThen", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate$1("ngxIfHasItemsThen", templateRef);
            this._thenTemplateRef = templateRef;
            this._thenViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfHasItemsDirective.prototype, "ngxIfHasItemsElse", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate$1("ngxIfHasItemsElse", templateRef);
            this._elseTemplateRef = templateRef;
            this._elseViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NgxIfHasItemsDirective.prototype._updateView = /**
     * @return {?}
     */
    function () {
        if (this._context.$implicit) {
            if (!this._thenViewRef) {
                this._viewContainer.clear();
                this._elseViewRef = null;
                if (this._thenTemplateRef) {
                    this._thenViewRef =
                        this._viewContainer.createEmbeddedView(this._thenTemplateRef, this._context);
                }
            }
        }
        else {
            if (!this._elseViewRef) {
                this._viewContainer.clear();
                this._thenViewRef = null;
                if (this._elseTemplateRef) {
                    this._elseViewRef =
                        this._viewContainer.createEmbeddedView(this._elseTemplateRef, this._context);
                }
            }
        }
        this.cd.markForCheck();
    };
    NgxIfHasItemsDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[ngxIfHasItems]"
                },] },
    ];
    /** @nocollapse */
    NgxIfHasItemsDirective.ctorParameters = function () { return [
        { type: ViewContainerRef, },
        { type: TemplateRef, },
        { type: ChangeDetectorRef, },
    ]; };
    NgxIfHasItemsDirective.propDecorators = {
        "ngxIfHasItems": [{ type: Input },],
        "ngxIfHasItemsThen": [{ type: Input },],
        "ngxIfHasItemsElse": [{ type: Input },],
    };
    return NgxIfHasItemsDirective;
}());
var NgxIfHasItemsContext = (function () {
    function NgxIfHasItemsContext() {
        this.$implicit = null;
        this.ngxIfHasItems = null;
    }
    return NgxIfHasItemsContext;
}());
/**
 * @param {?} property
 * @param {?} templateRef
 * @return {?}
 */
function assertTemplate$1(property, templateRef) {
    var /** @type {?} */ isTemplateRefOrNull = !!(!templateRef || templateRef.createEmbeddedView);
    if (!isTemplateRefOrNull) {
        throw new Error(property + " must be a TemplateRef, but received '" + (templateRef) + "'.");
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfHasItemsModule = (function () {
    function NgxIfHasItemsModule() {
    }
    NgxIfHasItemsModule.decorators = [
        { type: NgModule, args: [{
                    imports: [],
                    declarations: [
                        NgxIfHasItemsDirective
                    ],
                    exports: [
                        NgxIfHasItemsDirective
                    ]
                },] },
    ];
    return NgxIfHasItemsModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfNotEmptyDirective = (function () {
    function NgxIfNotEmptyDirective(_viewContainer, templateRef, cd) {
        this._viewContainer = _viewContainer;
        this.cd = cd;
        this._context = new NgxIfNotEmptyContext();
        this._thenTemplateRef = null;
        this._elseTemplateRef = null;
        this._thenViewRef = null;
        this._elseViewRef = null;
        this._thenTemplateRef = templateRef;
    }
    Object.defineProperty(NgxIfNotEmptyDirective.prototype, "ngxIfNotEmpty", {
        set: /**
         * @param {?} array
         * @return {?}
         */
        function (array) {
            this._context.ngxIfNotEmpty = array;
            this._context.$implicit = !isEmpty(array);
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfNotEmptyDirective.prototype, "ngxIfNotEmptyThen", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate$2("ngxIfNotEmptyThen", templateRef);
            this._thenTemplateRef = templateRef;
            this._thenViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxIfNotEmptyDirective.prototype, "ngxIfNotEmptyElse", {
        set: /**
         * @param {?} templateRef
         * @return {?}
         */
        function (templateRef) {
            assertTemplate$2("ngxIfNotEmptyElse", templateRef);
            this._elseTemplateRef = templateRef;
            this._elseViewRef = null; // clear previous view if any.
            this._updateView();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NgxIfNotEmptyDirective.prototype._updateView = /**
     * @return {?}
     */
    function () {
        if (this._context.$implicit) {
            if (!this._thenViewRef) {
                this._viewContainer.clear();
                this._elseViewRef = null;
                if (this._thenTemplateRef) {
                    this._thenViewRef =
                        this._viewContainer.createEmbeddedView(this._thenTemplateRef, this._context);
                }
            }
        }
        else {
            if (!this._elseViewRef) {
                this._viewContainer.clear();
                this._thenViewRef = null;
                if (this._elseTemplateRef) {
                    this._elseViewRef =
                        this._viewContainer.createEmbeddedView(this._elseTemplateRef, this._context);
                }
            }
        }
        this.cd.markForCheck();
    };
    NgxIfNotEmptyDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[ngxIfNotEmpty]"
                },] },
    ];
    /** @nocollapse */
    NgxIfNotEmptyDirective.ctorParameters = function () { return [
        { type: ViewContainerRef, },
        { type: TemplateRef, },
        { type: ChangeDetectorRef, },
    ]; };
    NgxIfNotEmptyDirective.propDecorators = {
        "ngxIfNotEmpty": [{ type: Input },],
        "ngxIfNotEmptyThen": [{ type: Input },],
        "ngxIfNotEmptyElse": [{ type: Input },],
    };
    return NgxIfNotEmptyDirective;
}());
var NgxIfNotEmptyContext = (function () {
    function NgxIfNotEmptyContext() {
        this.$implicit = null;
        this.ngxIfNotEmpty = null;
    }
    return NgxIfNotEmptyContext;
}());
/**
 * @param {?} property
 * @param {?} templateRef
 * @return {?}
 */
function assertTemplate$2(property, templateRef) {
    var /** @type {?} */ isTemplateRefOrNull = !!(!templateRef || templateRef.createEmbeddedView);
    if (!isTemplateRefOrNull) {
        throw new Error(property + " must be a TemplateRef, but received '" + (templateRef) + "'.");
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfNotEmptyModule = (function () {
    function NgxIfNotEmptyModule() {
    }
    NgxIfNotEmptyModule.decorators = [
        { type: NgModule, args: [{
                    imports: [],
                    declarations: [
                        NgxIfNotEmptyDirective
                    ],
                    exports: [
                        NgxIfNotEmptyDirective
                    ]
                },] },
    ];
    return NgxIfNotEmptyModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgxIfEmptyOrHasItemsModule = (function () {
    function NgxIfEmptyOrHasItemsModule() {
    }
    NgxIfEmptyOrHasItemsModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        NgxIfEmptyModule,
                        NgxIfHasItemsModule,
                        NgxIfNotEmptyModule
                    ],
                    exports: [
                        NgxIfEmptyModule,
                        NgxIfHasItemsModule,
                        NgxIfNotEmptyModule
                    ]
                },] },
    ];
    return NgxIfEmptyOrHasItemsModule;
}());

export { NgxIfEmptyOrHasItemsModule, NgxIfEmptyModule, NgxIfEmptyDirective, NgxIfEmptyContext, NgxIfHasItemsModule, NgxIfHasItemsDirective, NgxIfHasItemsContext, NgxIfNotEmptyModule, NgxIfNotEmptyDirective, NgxIfNotEmptyContext };
